@@ -510,6 +510,9 @@ class RequestSpec(base.NovaObject):
             if 'instance_group' in spec and spec.instance_group:
                 spec.instance_group.members = None
                 spec.instance_group.hosts = None
+            # NOTE(mriedem): Don't persist retries since those are per-request
+            if 'retry' in spec and spec.retry:
+                spec.retry = None
 
             db_updates = {'spec': jsonutils.dumps(spec.obj_to_primitive())}
             if 'instance_uuid' in updates:
