@@ -44,9 +44,6 @@ _RE_INV_IN_USE = re.compile("Inventory for (.+) on resource provider "
                             "(.+) in use")
 WARN_EVERY = 10
 PLACEMENT_CLIENT_SEMAPHORE = 'placement_client'
-# Number of seconds between attempts to update a provider's aggregates and
-# traits
-ASSOCIATION_REFRESH = 300
 NESTED_PROVIDER_API_VERSION = '1.14'
 POST_ALLOCATIONS_API_VERSION = '1.13'
 
@@ -662,6 +659,14 @@ class SchedulerReportClient(object):
             created_rp = self._create_resource_provider(
                 context, uuid, name or uuid,
                 parent_provider_uuid=parent_provider_uuid)
+            # If @safe_connect can't establish a connection to the placement
+            # service, like if placement isn't running or nova-compute is
+            # mis-configured for authentication, we'll get None back and need
+            # to treat it like we couldn't create the provider (because we
+            # couldn't).
+            if created_rp is None:
+                raise exception.ResourceProviderCreationFailed(
+                    name=name or uuid)
             # Don't add the created_rp to rps_to_refresh.  Since we just
             # created it, it has no aggregates or traits.
 
@@ -743,8 +748,8 @@ class SchedulerReportClient(object):
         sharing providers for the specified resource provider uuid.
 
         Only refresh if there has been no refresh during the lifetime of
-        this process, ASSOCIATION_REFRESH seconds have passed, or the force arg
-        has been set to True.
+        this process, CONF.compute.resource_provider_association_refresh
+        seconds have passed, or the force arg has been set to True.
 
         Note that we do *not* refresh inventories.  The reason is largely
         historical: all code paths that get us here are doing inventory refresh
@@ -812,10 +817,12 @@ class SchedulerReportClient(object):
         "recently".
 
         It is old if association_refresh_time for this uuid is not set
-        or more than ASSOCIATION_REFRESH seconds ago.
+        or more than CONF.compute.resource_provider_association_refresh
+        seconds ago.
         """
         refresh_time = self.association_refresh_time.get(uuid, 0)
-        return (time.time() - refresh_time) > ASSOCIATION_REFRESH
+        return ((time.time() - refresh_time) >
+                CONF.compute.resource_provider_association_refresh)
 
     def _update_inventory_attempt(self, context, rp_uuid, inv_data):
         """Update the inventory for this resource provider if needed.
